from HardwareMonitor.Hardware import Hardware, ISettings, IVisitor, ParameterDescription
from HardwareMonitor._util.types import AsyncCallback, Byte, IAsyncResult, IReadOnlyList, Int16, IntPtr, Nullable, Object, Single, UInt16, UInt32, UInt64
from typing import Set, Tuple, overload


class AbstractStorage(Hardware):
    def Close(self) -> None: ...
    def CreateInstance(deviceId: str, driveNumber: UInt32, diskSize: UInt64, scsiPort: int, settings: ISettings) -> AbstractStorage: ...
    @property
    def DriveInfos(self) -> Set[DriveInfo]: ...
    @property
    def FirmwareRevision(self) -> str: ...
    @property
    def HardwareType(self) -> HardwareType: ...
    @property
    def Index(self) -> int: ...
    def GetReport(self) -> str: ...
    def Traverse(self, visitor: IVisitor) -> None: ...
    def Update(self) -> None: ...


class AtaStorage(AbstractStorage):
    def Close(self) -> None: ...
    @property
    def Smart(self) -> ISmart: ...
    @property
    def SmartAttributes(self) -> IReadOnlyList: ...


class GenericHardDisk(AtaStorage):
    pass


class ISmart:
    def Close(self) -> None: ...
    def EnableSmart(self) -> bool: ...
    @property
    def IsValid(self) -> bool: ...
    def ReadNameAndFirmwareRevision(self) -> Tuple[bool, str, str]: ...
    def ReadSmartData(self) -> Set[SMART_ATTRIBUTE]: ...
    def ReadSmartThresholds(self) -> Set[SMART_THRESHOLD]: ...


class NVMeGeneric(AbstractStorage):
    def Close(self) -> None: ...
    @property
    def Smart(self) -> NVMeSmart: ...


class NVMeHealthInfo:
    @property
    def AvailableSpare(self) -> Byte: ...
    @property
    def AvailableSpareThreshold(self) -> Byte: ...
    @property
    def ControllerBusyTime(self) -> UInt64: ...
    @property
    def CriticalCompositeTemperatureTime(self) -> UInt32: ...
    @property
    def CriticalWarning(self) -> NVME_CRITICAL_WARNING: ...
    @property
    def DataUnitRead(self) -> UInt64: ...
    @property
    def DataUnitWritten(self) -> UInt64: ...
    @property
    def ErrorInfoLogEntryCount(self) -> UInt64: ...
    @property
    def HostReadCommands(self) -> UInt64: ...
    @property
    def HostWriteCommands(self) -> UInt64: ...
    @property
    def MediaErrors(self) -> UInt64: ...
    @property
    def PercentageUsed(self) -> Byte: ...
    @property
    def PowerCycle(self) -> UInt64: ...
    @property
    def PowerOnHours(self) -> UInt64: ...
    @property
    def Temperature(self) -> Int16: ...
    @property
    def TemperatureSensors(self) -> Set[Int16]: ...
    @property
    def UnsafeShutdowns(self) -> UInt64: ...
    @property
    def WarningCompositeTemperatureTime(self) -> UInt32: ...


class NVMeInfo:
    @property
    def ControllerId(self) -> UInt16: ...
    @property
    def IEEE(self) -> Set[Byte]: ...
    @property
    def Index(self) -> int: ...
    @property
    def Model(self) -> str: ...
    @property
    def NumberNamespaces(self) -> UInt32: ...
    @property
    def Revision(self) -> str: ...
    @property
    def Serial(self) -> str: ...
    @property
    def SSVID(self) -> UInt16: ...
    @property
    def TotalCapacity(self) -> UInt64: ...
    @property
    def UnallocatedCapacity(self) -> UInt64: ...
    @property
    def VID(self) -> UInt16: ...


class NVMeSmart:
    def Close(self) -> None: ...
    def Dispose(self) -> None: ...
    @property
    def IsValid(self) -> bool: ...
    def GetHealthInfo(self) -> NVMeHealthInfo: ...
    def GetInfo(self) -> NVMeInfo: ...


class RawValueConversion:
    def __init__(self, object: Object, method: IntPtr): ...
    def BeginInvoke(self, rawValue: Set[Byte], value: Byte, parameters: IReadOnlyList, callback: AsyncCallback, object: Object) -> IAsyncResult: ...
    def EndInvoke(self, result: IAsyncResult) -> Single: ...
    def Invoke(self, rawValue: Set[Byte], value: Byte, parameters: IReadOnlyList) -> Single: ...


class SmartAttribute:
    @overload
    def __init__(self, id: Byte, name: str): ...
    @overload
    def __init__(self, id: Byte, name: str, rawValueConversion: RawValueConversion): ...
    @overload
    def __init__(self, id: Byte, name: str, rawValueConversion: RawValueConversion, sensorType: Nullable, sensorChannel: int, sensorName: str, defaultHiddenSensor: bool, parameterDescriptions: Set[ParameterDescription]): ...
    @property
    def DefaultHiddenSensor(self) -> bool: ...
    @property
    def HasRawValueConversion(self) -> bool: ...
    @property
    def Id(self) -> Byte: ...
    @property
    def Name(self) -> str: ...
    @property
    def ParameterDescriptions(self) -> Set[ParameterDescription]: ...
    @property
    def SensorChannel(self) -> int: ...
    @property
    def SensorName(self) -> str: ...
    @property
    def SensorType(self) -> Nullable: ...


class SmartNames:
    @property
    def AirflowTemperature() -> str: ...
    @property
    def AlternativeEraseFailCount() -> str: ...
    @property
    def AlternativeGSenseErrorRate() -> str: ...
    @property
    def AlternativeProgramFailCount() -> str: ...
    @property
    def AvailableReservedSpace() -> str: ...
    @property
    def AverageEraseCount() -> str: ...
    @property
    def BadBlockFullFlag() -> str: ...
    @property
    def BitErrors() -> str: ...
    @property
    def CalibrationRetryCount() -> str: ...
    @property
    def CommandTimeout() -> str: ...
    @property
    def ControllerWritesToNand() -> str: ...
    @property
    def CorrectedErrors() -> str: ...
    @property
    def CrcErrorCount() -> str: ...
    @property
    def CurrentPendingSectorCount() -> str: ...
    @property
    def DataAddressMarkErrors() -> str: ...
    @property
    def DiskShift() -> str: ...
    @property
    def DriveTemperature() -> str: ...
    @property
    def EccRate() -> str: ...
    @property
    def EmergencyRetractCycleCount() -> str: ...
    @property
    def EndToEndError() -> str: ...
    @property
    def EnduranceRemaining() -> str: ...
    @property
    def EraseFailCount() -> str: ...
    @property
    def EraseFailCountChip() -> str: ...
    @property
    def EraseFailCountTotal() -> str: ...
    @property
    def EraseFailure() -> str: ...
    @property
    def ErrorCorrectionCount() -> str: ...
    @property
    def ExceptionModeStatus() -> str: ...
    @property
    def FactoryBadBlockCount() -> str: ...
    @property
    def FlyingHeight() -> str: ...
    @property
    def FreeFallProtection() -> str: ...
    @property
    def FTLProgramNANDPagesCount() -> str: ...
    @property
    def GmrHeadAmplitude() -> str: ...
    @property
    def GSenseErrorRate() -> str: ...
    @property
    def HardwareEccRecovered() -> str: ...
    @property
    def HeadFlyingHours() -> str: ...
    @property
    def HeadStability() -> str: ...
    @property
    def HighFlyWrites() -> str: ...
    @property
    def HostProgramNANDPagesCount() -> str: ...
    @property
    def HostReads() -> str: ...
    @property
    def HostWrites() -> str: ...
    @property
    def HostWritesToController() -> str: ...
    @property
    def InducedOpVibrationDetection() -> str: ...
    @property
    def InitialBadBlockCount() -> str: ...
    @property
    def LoadCycleCount() -> str: ...
    @property
    def LoadedHours() -> str: ...
    @property
    def LoadFriction() -> str: ...
    @property
    def LoadInTime() -> str: ...
    @property
    def LoadUnloadCycleCount() -> str: ...
    @property
    def LoadUnloadCycleCountFujitsu() -> str: ...
    @property
    def LoadUnloadRetryCount() -> str: ...
    @property
    def MaxCellCycles() -> str: ...
    @property
    def MaxErase() -> str: ...
    @property
    def MediaWearOutIndicator() -> str: ...
    @property
    def MinErase() -> str: ...
    @property
    def MultiZoneErrorRate() -> str: ...
    @property
    def NewFailingBlockCount() -> str: ...
    @property
    def Non4KAlignedAccess() -> str: ...
    @property
    def OfflineSeekPerformance() -> str: ...
    @property
    def OffLineUncorrectableErrorCount() -> str: ...
    @property
    def PowerCycleCount() -> str: ...
    @property
    def PowerOffRetractCycle() -> str: ...
    @property
    def PowerOnHours() -> str: ...
    @property
    def PowerRecoveryCount() -> str: ...
    @property
    def ProgramFailCount() -> str: ...
    @property
    def ProgramFailCountChip() -> str: ...
    @property
    def ProgramFailCountTotal() -> str: ...
    @property
    def ProgramFailure() -> str: ...
    @property
    def RawReadErrorRate() -> str: ...
    @property
    def ReadChannelMargin() -> str: ...
    @property
    def ReadCommands() -> str: ...
    @property
    def ReadErrorRate() -> str: ...
    @property
    def ReadErrorRetryRate() -> str: ...
    @property
    def ReadFailure() -> str: ...
    @property
    def ReallocatedNANDBlockCount() -> str: ...
    @property
    def ReallocatedSectorsCount() -> str: ...
    @property
    def ReallocationEventCount() -> str: ...
    @property
    def RecalibrationRetries() -> str: ...
    @property
    def RemainingLife() -> str: ...
    @property
    def ReportedUncorrectableErrors() -> str: ...
    @property
    def RetiredBlockCount() -> str: ...
    @property
    def RunOutCancel() -> str: ...
    @property
    def RuntimeBadBlockTotal() -> str: ...
    @property
    def SataDownshiftErrorCount() -> str: ...
    @property
    def SataErrorCountCrc() -> str: ...
    @property
    def SataErrorCountHandshake() -> str: ...
    @property
    def SectorsRead() -> str: ...
    @property
    def SectorsWritten() -> str: ...
    @property
    def SeekErrorRate() -> str: ...
    @property
    def SeekTimePerformance() -> str: ...
    @property
    def ShockDuringWrite() -> str: ...
    @property
    def SoftEccCorrection() -> str: ...
    @property
    def SoftReadErrorRate() -> str: ...
    @property
    def SpinBuzz() -> str: ...
    @property
    def SpinHighCurrent() -> str: ...
    @property
    def SpinRetryCount() -> str: ...
    @property
    def SpinUpTime() -> str: ...
    @property
    def StartStopCount() -> str: ...
    @property
    def SuccessfulRAINRecoveryCount() -> str: ...
    @property
    def SupercapStatus() -> str: ...
    @property
    def TaCounterDetected() -> str: ...
    @property
    def Temperature() -> str: ...
    @property
    def TemperatureDifferenceFrom100() -> str: ...
    @property
    def TemperatureExceedCount() -> str: ...
    @property
    def ThermalAsperityRate() -> str: ...
    @property
    def ThroughputPerformance() -> str: ...
    @property
    def TorqueAmplificationCount() -> str: ...
    @property
    def TotalLbasRead() -> str: ...
    @property
    def TotalLbasWritten() -> str: ...
    @property
    def TransferErrorRate() -> str: ...
    @property
    def UltraDmaCrcErrorCount() -> str: ...
    @property
    def UncorrectableErrorCount() -> str: ...
    @property
    def UncorrectableSectorCount() -> str: ...
    @property
    def UnexpectedPowerLossCount() -> str: ...
    @property
    def Unknown() -> str: ...
    @property
    def UnknownUnique() -> str: ...
    @property
    def UnrecoverableEcc() -> str: ...
    @property
    def UnsafeShutdownCount() -> str: ...
    @property
    def UnusedReserveNANDBlocks() -> str: ...
    @property
    def UsedReservedBlockCountChip() -> str: ...
    @property
    def UsedReservedBlockCountTotal() -> str: ...
    @property
    def VibrationDuringWrite() -> str: ...
    @property
    def WearLevelingCount() -> str: ...
    @property
    def WearRangeDelta() -> str: ...
    @property
    def WriteCommands() -> str: ...
    @property
    def WriteErrorRate() -> str: ...
